;; Generated package description from djvu.el  -*- no-byte-compile: t -*-
(define-package "djvu" "1.1.2.0.20220416.215157" "Edit and view Djvu files via djvused" 'nil :commit "071c8ab168588897475899c46eaa16e70141db8c" :url "https://elpa.gnu.org/packages/djvu.html" :authors '(("Roland Winkler" . "winkler@gnu.org")) :maintainer '("Roland Winkler" . "winkler@gnu.org") :keywords '("files" "wp"))
